@@ -10,7 +10,7 @@ def test_encryption_example():
     data = bytes(bytearray.fromhex("2302CA090303BF13"))  # BTHome data (not encrypted)
     count_id = bytes(bytearray.fromhex("00112233"))  # count id (change every message)
     mac = binascii.unhexlify("5448E68F80A5")  # MAC
-    uuid16 = b"\x1E\x18"
+    uuid16 = b"\x1e\x18"
     bindkey = binascii.unhexlify("231d39c1d7cc1ab1aee224cd096db932")
 
     payload = encrypt_payload(
